/*****************************************************************************
 * Copyright (C) 1997-2007, Mark Hummel
 * This file is part of Vrq.
 *
 * Vrq is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * Vrq is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, 
 * Boston, MA  02110-1301  USA
 *****************************************************************************
 */
/******************************************************************************
 *
 *
 *	   cportdir.hpp
 *		- class definition of port direction
 *		  definition nodes
 *
 ******************************************************************************
 */

#ifndef CPORTDIR_HPP
#define CPORTDIR_HPP

#include <stdio.h>
#include "glue.h"
#include "cnode.h"
#include "cdecl.h"


class CNode;

/**
 * Declaration object for input/output/inout statements.
 */
class CPortDir : public CDecl
{
private:
	CDecl*	decl;		///< variable declaration association
	Decl_t	portType;	///< port declaration type
public:
	/**
 	 * Create a port direction declaration.
 	 * \param symbol name of declaration.
	 * \param aLoc file coordinates of declaration.
	 * \param type port declaration type.
	 */
	CPortDir( CSymbol* symbol, Coord_t* aLoc, Decl_t type );
	/**
 	 * Dump declaration to file descriptor.
	 * \param f file descriptor.
	 */
	virtual void Dump( FILE* f );
	/**
 	 * Get variable declaration associated with this.
 	 * \return variable declaration.
	 */
	CDecl* GetDecl( void ) { return decl; }
	/**
 	 * Set association to variable declaration.
 	 * \param d variable declaration.
 	 */
	void SetDecl( CDecl* d ) { decl = d; }
	/**
 	 * Set port type for declaration.
 	 * \param t port type: eINPUT, eOUTPUT, eINOUT.
 	 */
	void SetPortType( Decl_t t ) { portType = t; }
	/**
 	 * Get port type of declaration.
 	 * \return port type: eINPUT, eOUTPUT, eINOUT.
 	 */
	Decl_t GetPortType() { return portType; }
	/**
 	 * Get node expression type
 	 * \return node type.
 	 */
	virtual NodeType_t GetNodeType()  { return GetSigned() ? eS : eB; }
};

#endif // CPORT_HPP
