/*****************************************************************************
 * Copyright (C) 1997-2007, Mark Hummel
 * This file is part of Vrq.
 *
 * Vrq is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * Vrq is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, 
 * Boston, MA  02110-1301  USA
 *****************************************************************************
 */
/******************************************************************************
 *
 *
 *	   creg.hpp
 *		- class definition of register
 *		  definition nodes
 *
 ******************************************************************************
 */

#ifndef CREG_HPP
#define CREG_HPP

#include <stdio.h>
#include "glue.h"
#include "cnode.h"
#include "cdecl.h"


class CNode;

/*
 * handle decl types:
 *	eTIME
 *	eINT
 *	eREG
 */

/**
 * Declaration object for registers.
 */
class CReg: public CDecl
{
private:
	int	undefined;	// TRUE if undefined in source
public:
	/**
 	 * Create a register declaration.
 	 * \param symbol declaration symbol.
 	 * \param aLoc file coordinates.
 	 * \param type declaration type. ie eTIME, eINT, eREG.
 	 * \param undefined non-zero if register is undefined in source.
 	 */
	CReg( CSymbol* symbol, Coord_t* aLoc, Decl_t type, int undefined );
	/**
 	 * Create and copy (deep) register declaration.
 	 */
	CReg( const CReg& reg );
	/**
 	 * Get undefined attribute.
 	 * \return undefined attribute.
 	 */
	int	GetUndefined( void ) { return undefined; }
	/**
 	 * Set undefined attribute.
 	 * \param value set undefined attribute.
 	 */
	void	SetUndefined( int value ) { undefined = value; }
	/**
 	 * Dump register info to file.
 	 * \param f file descriptor.
 	 */
	virtual void Dump( FILE* f );
	/**
 	 * Get node type
 	 * \return node type.
 	 */
	virtual NodeType_t GetNodeType( void ) { return GetSigned() ? eS : eB; }
};

#endif // CREG_HPP
